package rap.tinymce;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.framework.ServiceEvent;
import org.osgi.framework.ServiceListener;
import org.osgi.framework.ServiceReference;
import org.osgi.service.http.HttpService;
import org.osgi.service.http.NamespaceException;

/**
 * The activator class controls the plug-in life cycle
 */
public class Activator extends AbstractUIPlugin {

	// The plug-in ID
	public static final String PLUGIN_ID = "scrapbook.RAP.TinyMCE";

	// The shared instance
	private static Activator plugin;

	/**
	 * The constructor
	 */
	public Activator() {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext
	 * )
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
		createListener(context);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext
	 * )
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 * 
	 * @return the shared instance
	 */
	public static Activator getDefault() {
		return plugin;
	}

	/**
	 * Returns an image descriptor for the image file at the given plug-in
	 * relative path
	 * 
	 * @param path
	 *            the path
	 * @return the image descriptor
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(PLUGIN_ID, path);
	}

	private void createListener(final BundleContext context) {

		ServiceListener sl = new ServiceListener() {

			public void serviceChanged(ServiceEvent ev) {
				ServiceReference sr = ev.getServiceReference();
				switch (ev.getType()) {
				case ServiceEvent.REGISTERED: {
					HttpService http = (HttpService) context.getService(sr);
					try {
						http.registerResources("/tiny_mce", "/tiny_mce", null); //$NON-NLS-1$//$NON-NLS-2$
					} catch (NamespaceException e) {
						e.printStackTrace();
					}
				}
				default:
				}
			}
		};

		String filter = "(objectclass=" + HttpService.class.getName() + ")"; //$NON-NLS-1$//$NON-NLS-2$
		try {
			context.addServiceListener(sl, filter);
			ServiceReference[] srl = context.getServiceReferences(null, filter);
			for (int i = 0; srl != null && i < srl.length; i++) {
				sl.serviceChanged(new ServiceEvent(ServiceEvent.REGISTERED,
						srl[i]));
			}
		} catch (InvalidSyntaxException e) {
			e.printStackTrace();
		}
	}

}
