package rap.tinymce;

import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.Platform;
import org.eclipse.rwt.RWT;

public class Utils {

	public static String getPluginLocation() {
		URL result = Platform.getBundle( Activator.PLUGIN_ID ).getEntry("/");
		try {
			result = FileLocator.resolve(result);
		}
		catch (IOException ioe){}
		
		if ( System.getProperty("os.name").toLowerCase().startsWith("windows") ) {
			return result.getFile().substring(1).replaceAll("/", "\\\\");
		}
		else {
			return result.getFile();
		}
		
	}
	
    /**
     * Register all resources, recursively under specified folder
     * <br />
     * search path = plugin root location
     * 
     * @param clazz - executor class
     * @param folder - folder name
     * @param exclude - compared by filename.startsWith(exclude[*]) 
     */
    public static void registerResources(Class<?> clazz, String folder, String...exclude) {
    	RWT.getResourceManager().setContextLoader(clazz.getClassLoader());
    	
    	File pluginRoot = new File(Utils.getPluginLocation());
    	System.out.println("pluginRoot = " + Utils.getPluginLocation());
    	File tFolder = new File(pluginRoot, folder);
		List<String> collectedPaths = new ArrayList<String>();
		getContents(tFolder, collectedPaths, exclude);
		for ( Iterator<String> iter = collectedPaths.iterator(); iter.hasNext(); ) {
			String next = iter.next();
			String resource = next.replace(Utils.getPluginLocation(), "");
			if ( !RWT.getResourceManager().isRegistered(resource) ) {
				RWT.getResourceManager().register(resource);
				System.out.println("registered resource ->" + resource);
			}
		}
    }
    
    private static void getContents(File f, List<String> collectedPaths, final String...exclude) {
    	if ( f.exists() ) {
    		if ( f.isDirectory() ) {
    			File[] files = f.listFiles(new FilenameFilter(){
    				@Override
    				public boolean accept(File dir, String name) {
    					if ( exclude != null ) {
    						boolean accept = true;
    						for ( String str : exclude ) {
    							if ( name.startsWith(str) ) {
    								accept = false;
    								break;
    							}
    								
    						}
    						return accept;
    					}
    					else
    						return true;
    				}
    			});
    			for ( File file : files ) {
					if ( file.isDirectory() )
    					getContents(file, collectedPaths, exclude);
    				else
    					collectedPaths.add(file.getAbsolutePath());
    			}
    		}
    		else {
				collectedPaths.add(f.getAbsolutePath());
    		}
    	}
    }
	
}
